==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cfg/kotlin/inputs/OrganizationConformancePackInputParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cfg.kotlin.inputs

import com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property parameterName The input key.
 * @property parameterValue The input value.
 */
public data class OrganizationConformancePackInputParameterArgs(
    public val parameterName: Output<String>,
    public val parameterValue: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs> {
    override fun toJava(): com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs =
        com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs.builder()
            .parameterName(parameterName.applyValue({ args0 -> args0 }))
            .parameterValue(parameterValue.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OrganizationConformancePackInputParameterArgs].
 */
@PulumiTagMarker
public class OrganizationConformancePackInputParameterArgsBuilder internal constructor() {
    private var parameterName: Output<String>? = null

    private var parameterValue: Output<String>? = null

    /**
     * @param value The input key.
     */
    @JvmName("dbbjubtscuchnibk")
    public suspend fun parameterName(`value`: Output<String>) {
        this.parameterName = value
    }

    /**
     * @param value The input value.
     */
    @JvmName("jkgqqpqjamqqixdg")
    public suspend fun parameterValue(`value`: Output<String>) {
        this.parameterValue = value
    }

    /**
     * @param value The input key.
     */
    @JvmName("taardcloquhnllio")
    public suspend fun parameterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameterName = mapped
    }

    /**
     * @param value The input value.
     */
    @JvmName("ggrqrsqxhxtkskln")
    public suspend fun parameterValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameterValue = mapped
    }

    internal fun build(): OrganizationConformancePackInputParameterArgs =
        OrganizationConformancePackInputParameterArgs(
            parameterName = parameterName ?: throw PulumiNullFieldException("parameterName"),
            parameterValue = parameterValue ?: throw PulumiNullFieldException("parameterValue"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cfg/kotlin/inputs/OrganizationConformancePackInputParameterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cfg.kotlin.inputs

import com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property parameterName The input key.
 * @property parameterValue The input value.
 */
public data class OrganizationConformancePackInputParameterArgs(
    public val parameterName: Output<String>,
    public val parameterValue: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs> {
    override fun toJava(): com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs =
        com.pulumi.aws.cfg.inputs.OrganizationConformancePackInputParameterArgs.builder()
            .parameterName(parameterName.applyValue({ args0 -> args0 }))
            .parameterValue(parameterValue.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [OrganizationConformancePackInputParameterArgs].
 */
@PulumiTagMarker
public class OrganizationConformancePackInputParameterArgsBuilder internal constructor() {
    private var parameterName: Output<String>? = null

    private var parameterValue: Output<String>? = null

    /**
     * @param value The input key.
     */
    @JvmName("dlxfgqqvgpxtcwgk")
    public suspend fun parameterName(`value`: Output<String>) {
        this.parameterName = value
    }

    /**
     * @param value The input value.
     */
    @JvmName("rtaoqtjsktbxihem")
    public suspend fun parameterValue(`value`: Output<String>) {
        this.parameterValue = value
    }

    /**
     * @param value The input key.
     */
    @JvmName("xtctwqxgewvxmtnr")
    public suspend fun parameterName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameterName = mapped
    }

    /**
     * @param value The input value.
     */
    @JvmName("khynrmwssphkagjo")
    public suspend fun parameterValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.parameterValue = mapped
    }

    internal fun build(): OrganizationConformancePackInputParameterArgs =
        OrganizationConformancePackInputParameterArgs(
            parameterName = parameterName ?: throw PulumiNullFieldException("parameterName"),
            parameterValue = parameterValue ?: throw PulumiNullFieldException("parameterValue"),
        )
}
